==> pentest_tls-0.1.5-py3-none-any.whl: pentest_tls/cli/pentest_tls_cli.py <==
#!/usr/bin/env python3

import argparse
import sys
import pyfiglet

from pentest_tls import port_scanner, util
from . import port_scanner_cli

help_text = """
Pentest Tools - Lightweight Pentest Toolkit

Usage:
  pentest_tls <ip> [options]

Positional Arguments:
  ip                        Target IPv4 address (e.g., 192.168.1.1)

Optional Arguments:
  -t, --type                Tool type to use. Currently supported:
                              PS   - Port Scanner
  -p, --ports               Port(s) to scan. Use comma-separated values (e.g., 22,80)
                           or a range (e.g., 1-1000). If omitted, a default set is used.
  -h, --help                Show this help message and exit

Examples:
  pentest_tls 192.168.1.10 -t PS
  pentest_tls 192.168.1.10 -t PS -p 22,80,443
  pentest_tls 192.168.1.10 -t PS -p 1-1000

Note:
  - Only IPv4 addresses are supported.
  - Tool types must be valid and recognized by the toolkit.
"""

def main():
    """
    Process all arguments, invoke specific module to achieve different functionality
    """
    banner = pyfiglet.figlet_format("Pentest Tools")
    print(banner)

    parser = argparse.ArgumentParser(description="Lightweight Pentest Toolkit")
    parser.add_argument("ip", help="Target IP address")
    parser.add_argument("-t", "--type", help="Tools refer to use. E.g. PS(for port scanner)")
    parser.add_argument("-p", "--ports", help="Port(s) to scan. E.g. 22,80 or 1-1000")
    args = parser.parse_args()

    if not util.is_valid_ipv4(args.ip):
        print("FormatError: Invalid IPv4 address.")
        sys.exit(1)
    elif not util.is_valid_type(args.type):
        print("FormatError: Invalid type category.")
        sys.exit(1)

    try:
        if args.ports:
            ports = port_scanner.parse_ports(args.ports)
        else:
            ports = port_scanner.load_default_ports()
    except ValueError as e:
        print(f"FormatError: {e}")
        sys.exit(1)

    # Port Scanner Logic
    if args.type == "PS":
        port_scanner_cli.process(ports, args.ip)

if __name__ == "__main__":
    main()

==> pentest_tls-0.1.7-py3-none-any.whl: pentest_tls/cli/pentest_tls_cli.py <==
#!/usr/bin/env python3

import argparse
import sys
import pyfiglet

from pentest_tls import util
from . import port_scanner_cli

"""
Pentest Tools - Lightweight Pentest Toolkit

Usage:
  pentest_tls <ip> [options]

Positional Arguments:
  ip                        Target IPv4 address (e.g., 192.168.1.1)

Optional Arguments:
  -t, --type                Tool type to use. Currently supported:
                              PS   - Port Scanner
  -p, --ports               Port(s) to scan. Use comma-separated values (e.g., 22,80)
                           or a range (e.g., 1-1000). If omitted, a default set is used.
  -h, --help                Show this help message and exit

Examples:
  pentest_tls 192.168.1.10 -t PS
  pentest_tls 192.168.1.10 -t PS -p 22,80,443
  pentest_tls 192.168.1.10 -t PS -p 1-1000

Note:
  - Only IPv4 addresses are supported.
  - Tool types must be valid and recognized by the toolkit.
"""

def main():
    """
    Process all arguments, invoke specific module to achieve different functionality
    """
    banner = pyfiglet.figlet_format("Pentest Tools")
    print(banner)

    parser = argparse.ArgumentParser(description="Lightweight Pentest Toolkit")
    parser.add_argument("ip", help="Target IP address")
    parser.add_argument("-t", "--type", help="Tools refer to use. E.g. PS(for port scanner)")
    parser.add_argument("-p", "--ports", help="Port(s) to scan. E.g. 22,80 or 1-1000")
    parser.add_argument("-PU", "--ps_udp", help="Use UDP ping for port scan")
    parser.add_argument("-PS", "--ps_tcp", help="Use TCP SYN packet for port scan")
    args = parser.parse_args()

    if not util.is_valid_ipv4(args.ip):
        print("FormatError: Invalid IPv4 address.")
        sys.exit(1)
    elif not util.is_valid_type(args.type):
        print("FormatError: Invalid type category.")
        sys.exit(1)

    try:
        if args.ports:
            ports = util.parse_ports(args.ports)
        else:
            ports = util.load_default_ports()
    except ValueError as e:
        print(f"FormatError: {e}")
        sys.exit(1)

    # Port Scanner Logic
    if args.type == "PS":
        port_scanner_cli.process(ports, args.ip, args.ps_udp, args.ps_tcp)

if __name__ == "__main__":
    main()
